@@ -72,6 +72,7 @@ Usage::
         DescribeScheduledInstancesPaginator,
         DescribeSecurityGroupRulesPaginator,
         DescribeSecurityGroupsPaginator,
+        DescribeSnapshotTierStatusPaginator,
         DescribeSnapshotsPaginator,
         DescribeSpotFleetInstancesPaginator,
         DescribeSpotFleetRequestsPaginator,
@@ -129,6 +130,7 @@ Usage::
         InstanceStoppedWaiter,
         InstanceTerminatedWaiter,
         KeyPairExistsWaiter,
+        ListSnapshotsInRecycleBinPaginator,
         NatGatewayAvailableWaiter,
         NetworkInterfaceAvailableWaiter,
         PasswordDataAvailableWaiter,
@@ -252,6 +254,7 @@ Usage::
     describe_scheduled_instances_paginator: DescribeScheduledInstancesPaginator = client.get_paginator("describe_scheduled_instances")
     describe_security_group_rules_paginator: DescribeSecurityGroupRulesPaginator = client.get_paginator("describe_security_group_rules")
     describe_security_groups_paginator: DescribeSecurityGroupsPaginator = client.get_paginator("describe_security_groups")
+    describe_snapshot_tier_status_paginator: DescribeSnapshotTierStatusPaginator = client.get_paginator("describe_snapshot_tier_status")
     describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
     describe_spot_fleet_instances_paginator: DescribeSpotFleetInstancesPaginator = client.get_paginator("describe_spot_fleet_instances")
     describe_spot_fleet_requests_paginator: DescribeSpotFleetRequestsPaginator = client.get_paginator("describe_spot_fleet_requests")
@@ -297,6 +300,7 @@ Usage::
     get_transit_gateway_route_table_associations_paginator: GetTransitGatewayRouteTableAssociationsPaginator = client.get_paginator("get_transit_gateway_route_table_associations")
     get_transit_gateway_route_table_propagations_paginator: GetTransitGatewayRouteTablePropagationsPaginator = client.get_paginator("get_transit_gateway_route_table_propagations")
     get_vpn_connection_device_types_paginator: GetVpnConnectionDeviceTypesPaginator = client.get_paginator("get_vpn_connection_device_types")
+    list_snapshots_in_recycle_bin_paginator: ListSnapshotsInRecycleBinPaginator = client.get_paginator("list_snapshots_in_recycle_bin")
     search_local_gateway_routes_paginator: SearchLocalGatewayRoutesPaginator = client.get_paginator("search_local_gateway_routes")
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
     ```
@@ -364,6 +368,7 @@ from .paginator import (
     DescribeSecurityGroupRulesPaginator,
     DescribeSecurityGroupsPaginator,
     DescribeSnapshotsPaginator,
+    DescribeSnapshotTierStatusPaginator,
     DescribeSpotFleetInstancesPaginator,
     DescribeSpotFleetRequestsPaginator,
     DescribeSpotInstanceRequestsPaginator,
@@ -408,6 +413,7 @@ from .paginator import (
     GetTransitGatewayRouteTableAssociationsPaginator,
     GetTransitGatewayRouteTablePropagationsPaginator,
     GetVpnConnectionDeviceTypesPaginator,
+    ListSnapshotsInRecycleBinPaginator,
     SearchLocalGatewayRoutesPaginator,
     SearchTransitGatewayMulticastGroupsPaginator,
 )
@@ -520,6 +526,7 @@ __all__ = (
     "DescribeScheduledInstancesPaginator",
     "DescribeSecurityGroupRulesPaginator",
     "DescribeSecurityGroupsPaginator",
+    "DescribeSnapshotTierStatusPaginator",
     "DescribeSnapshotsPaginator",
     "DescribeSpotFleetInstancesPaginator",
     "DescribeSpotFleetRequestsPaginator",
@@ -577,6 +584,7 @@ __all__ = (
     "InstanceStoppedWaiter",
     "InstanceTerminatedWaiter",
     "KeyPairExistsWaiter",
+    "ListSnapshotsInRecycleBinPaginator",
     "NatGatewayAvailableWaiter",
     "NetworkInterfaceAvailableWaiter",
     "PasswordDataAvailableWaiter",
