@@ -144,6 +144,7 @@ __all__ = (
     "DescribeScheduledInstancesPaginatorName",
     "DescribeSecurityGroupRulesPaginatorName",
     "DescribeSecurityGroupsPaginatorName",
+    "DescribeSnapshotTierStatusPaginatorName",
     "DescribeSnapshotsPaginatorName",
     "DescribeSpotFleetInstancesPaginatorName",
     "DescribeSpotFleetRequestsPaginatorName",
@@ -269,6 +270,7 @@ __all__ = (
     "LaunchTemplateInstanceMetadataEndpointStateType",
     "LaunchTemplateInstanceMetadataOptionsStateType",
     "LaunchTemplateInstanceMetadataProtocolIpv6Type",
+    "ListSnapshotsInRecycleBinPaginatorName",
     "ListingStateType",
     "ListingStatusType",
     "LocalGatewayRouteStateType",
@@ -344,6 +346,7 @@ __all__ = (
     "StatusNameType",
     "StatusType",
     "StatusTypeType",
+    "StorageTierType",
     "SubnetAvailableWaiterName",
     "SubnetCidrBlockStateCodeType",
     "SubnetCidrReservationTypeType",
@@ -351,8 +354,10 @@ __all__ = (
     "SummaryStatusType",
     "SystemStatusOkWaiterName",
     "TargetCapacityUnitTypeType",
+    "TargetStorageTierType",
     "TelemetryStatusType",
     "TenancyType",
+    "TieringOperationStatusType",
     "TrafficDirectionType",
     "TrafficMirrorFilterRuleFieldType",
     "TrafficMirrorNetworkServiceType",
@@ -619,6 +624,7 @@ DescribeScheduledInstanceAvailabilityPaginatorName = Literal[
 DescribeScheduledInstancesPaginatorName = Literal["describe_scheduled_instances"]
 DescribeSecurityGroupRulesPaginatorName = Literal["describe_security_group_rules"]
 DescribeSecurityGroupsPaginatorName = Literal["describe_security_groups"]
+DescribeSnapshotTierStatusPaginatorName = Literal["describe_snapshot_tier_status"]
 DescribeSnapshotsPaginatorName = Literal["describe_snapshots"]
 DescribeSpotFleetInstancesPaginatorName = Literal["describe_spot_fleet_instances"]
 DescribeSpotFleetRequestsPaginatorName = Literal["describe_spot_fleet_requests"]
@@ -947,6 +953,12 @@ InstanceTypeType = Literal[
     "g5.4xlarge",
     "g5.8xlarge",
     "g5.xlarge",
+    "g5g.16xlarge",
+    "g5g.2xlarge",
+    "g5g.4xlarge",
+    "g5g.8xlarge",
+    "g5g.metal",
+    "g5g.xlarge",
     "h1.16xlarge",
     "h1.2xlarge",
     "h1.4xlarge",
@@ -972,10 +984,22 @@ InstanceTypeType = Literal[
     "i3en.large",
     "i3en.metal",
     "i3en.xlarge",
+    "im4gn.16xlarge",
+    "im4gn.2xlarge",
+    "im4gn.4xlarge",
+    "im4gn.8xlarge",
+    "im4gn.large",
+    "im4gn.xlarge",
     "inf1.24xlarge",
     "inf1.2xlarge",
     "inf1.6xlarge",
     "inf1.xlarge",
+    "is4gen.2xlarge",
+    "is4gen.4xlarge",
+    "is4gen.8xlarge",
+    "is4gen.large",
+    "is4gen.medium",
+    "is4gen.xlarge",
     "m1.large",
     "m1.medium",
     "m1.small",
@@ -1052,6 +1076,16 @@ InstanceTypeType = Literal[
     "m5zn.large",
     "m5zn.metal",
     "m5zn.xlarge",
+    "m6a.12xlarge",
+    "m6a.16xlarge",
+    "m6a.24xlarge",
+    "m6a.2xlarge",
+    "m6a.32xlarge",
+    "m6a.48xlarge",
+    "m6a.4xlarge",
+    "m6a.8xlarge",
+    "m6a.large",
+    "m6a.xlarge",
     "m6g.12xlarge",
     "m6g.16xlarge",
     "m6g.2xlarge",
@@ -1261,6 +1295,7 @@ LaunchTemplateHttpTokensStateType = Literal["optional", "required"]
 LaunchTemplateInstanceMetadataEndpointStateType = Literal["disabled", "enabled"]
 LaunchTemplateInstanceMetadataOptionsStateType = Literal["applied", "pending"]
 LaunchTemplateInstanceMetadataProtocolIpv6Type = Literal["disabled", "enabled"]
+ListSnapshotsInRecycleBinPaginatorName = Literal["list_snapshots_in_recycle_bin"]
 ListingStateType = Literal["available", "cancelled", "pending", "sold"]
 ListingStatusType = Literal["active", "cancelled", "closed", "pending"]
 LocalGatewayRouteStateType = Literal["active", "blackhole", "deleted", "deleting", "pending"]
@@ -1428,7 +1463,7 @@ ServiceTypeType = Literal["Gateway", "GatewayLoadBalancer", "Interface"]
 ShutdownBehaviorType = Literal["stop", "terminate"]
 SnapshotAttributeNameType = Literal["createVolumePermission", "productCodes"]
 SnapshotCompletedWaiterName = Literal["snapshot_completed"]
-SnapshotStateType = Literal["completed", "error", "pending"]
+SnapshotStateType = Literal["completed", "error", "pending", "recoverable", "recovering"]
 SpotAllocationStrategyType = Literal[
     "capacity-optimized", "capacity-optimized-prioritized", "diversified", "lowest-price"
 ]
@@ -1450,6 +1485,7 @@ StaticSourcesSupportValueType = Literal["disable", "enable"]
 StatusNameType = Literal["reachability"]
 StatusType = Literal["InClassic", "InVpc", "MoveInProgress"]
 StatusTypeType = Literal["failed", "initializing", "insufficient-data", "passed"]
+StorageTierType = Literal["archive", "standard"]
 SubnetAvailableWaiterName = Literal["subnet_available"]
 SubnetCidrBlockStateCodeType = Literal[
     "associated", "associating", "disassociated", "disassociating", "failed", "failing"
@@ -1459,8 +1495,20 @@ SubnetStateType = Literal["available", "pending"]
 SummaryStatusType = Literal["impaired", "initializing", "insufficient-data", "not-applicable", "ok"]
 SystemStatusOkWaiterName = Literal["system_status_ok"]
 TargetCapacityUnitTypeType = Literal["memory-mib", "units", "vcpu"]
+TargetStorageTierType = Literal["archive"]
 TelemetryStatusType = Literal["DOWN", "UP"]
 TenancyType = Literal["dedicated", "default", "host"]
+TieringOperationStatusType = Literal[
+    "archival-completed",
+    "archival-failed",
+    "archival-in-progress",
+    "permanent-restore-completed",
+    "permanent-restore-failed",
+    "permanent-restore-in-progress",
+    "temporary-restore-completed",
+    "temporary-restore-failed",
+    "temporary-restore-in-progress",
+]
 TrafficDirectionType = Literal["egress", "ingress"]
 TrafficMirrorFilterRuleFieldType = Literal[
     "description", "destination-port-range", "protocol", "source-port-range"
@@ -1589,6 +1637,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -1665,6 +1714,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -1691,6 +1741,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -1704,6 +1755,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -1749,6 +1801,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -1779,6 +1832,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -1794,6 +1848,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -1851,6 +1906,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
 PaginatorName = Literal[
@@ -1914,6 +1970,7 @@ PaginatorName = Literal[
     "describe_scheduled_instances",
     "describe_security_group_rules",
     "describe_security_groups",
+    "describe_snapshot_tier_status",
     "describe_snapshots",
     "describe_spot_fleet_instances",
     "describe_spot_fleet_requests",
@@ -1959,6 +2016,7 @@ PaginatorName = Literal[
     "get_transit_gateway_route_table_associations",
     "get_transit_gateway_route_table_propagations",
     "get_vpn_connection_device_types",
+    "list_snapshots_in_recycle_bin",
     "search_local_gateway_routes",
     "search_transit_gateway_multicast_groups",
 ]
